@@ -2,16 +2,15 @@
 #'
 #' @param nchars number of characters. One of the two params should be left NULL.
 #' @param nwords number of words to return. One of the two params should be left NULL.
+#' @param offset number of characters or words to offset the result by. Defaults to 0.
 #'
 #' @importFrom attempt stop_if_all
 #'
 #' @return a text
 #'
 #' @export
-#' @examples
-#' random_text(nchars = 100)
-#' random_text(nwords = 100)
-random_text <- function(nchars = NULL, nwords = NULL){
+
+random_text <- function(nchars = NULL, nwords = NULL, offset=0){
   stop_if_all(
     c(nchars, nwords),
     is.null,
@@ -26,12 +25,14 @@ random_text <- function(nchars = NULL, nwords = NULL){
   if (!is.null(nchars)){
     res <- substr(
       shinipsum::lorem,
-      1,
-      nchars
+      1+offset,
+      nchars+offset
     )
   } else {
-    res <- paste(shinipsum::lorem_words[1:nwords], collapse = " ")
+    res <- paste(shinipsum::lorem_words[1+offset:nwords+offset], collapse = " ")
   }
+
+  substr(res, 1, 1) <- toupper(substr(res, 1, 1))
   res
 }
 
